@@ -1,4 +1,6 @@
-from datetime import date, datetime, timedelta
+from datetime import date
+from datetime import datetime
+from datetime import timedelta
 from unittest.mock import patch
 
 import pytest
@@ -8,50 +10,43 @@ from dateutil.tz.tz import tzoffset
 from freezegun import freeze_time
 
 from todoman.exceptions import AlreadyExists
-from todoman.model import cached_property, Database, List, Todo
+from todoman.model import cached_property
+from todoman.model import Database
+from todoman.model import List
+from todoman.model import Todo
 
 
 def test_querying(create, tmpdir):
-    for list in 'abc':
-        for i, location in enumerate('abc'):
+    for list in "abc":
+        for i, location in enumerate("abc"):
             create(
-                'test{}.ics'.format(i),
-                ('SUMMARY:test_querying\r\n'
-                 'LOCATION:{}\r\n').format(location),
-                list_name=list
+                "test{}.ics".format(i),
+                ("SUMMARY:test_querying\r\nLOCATION:{}\r\n").format(location),
+                list_name=list,
             )
 
-    db = Database([str(tmpdir.ensure_dir(l)) for l in 'abc'],
-                  str(tmpdir.join('cache')))
+    db = Database(
+        [str(tmpdir.ensure_dir(list_)) for list_ in "abc"], str(tmpdir.join("cache"))
+    )
 
     assert len(set(db.todos())) == 9
-    assert len(set(db.todos(lists='ab'))) == 6
-    assert len(set(db.todos(lists='ab', location='a'))) == 2
+    assert len(set(db.todos(lists="ab"))) == 6
+    assert len(set(db.todos(lists="ab", location="a"))) == 2
 
 
 def test_retain_tz(tmpdir, create, todos):
-    create(
-        'ar.ics', 'SUMMARY:blah.ar\n'
-        'DUE;VALUE=DATE-TIME;TZID=HST:20160102T000000\n'
-    )
-    create(
-        'de.ics', 'SUMMARY:blah.de\n'
-        'DUE;VALUE=DATE-TIME;TZID=CET:20160102T000000\n'
-    )
+    create("ar.ics", "SUMMARY:blah.ar\nDUE;VALUE=DATE-TIME;TZID=HST:20160102T000000\n")
+    create("de.ics", "SUMMARY:blah.de\nDUE;VALUE=DATE-TIME;TZID=CET:20160102T000000\n")
 
     todos = list(todos())
 
     assert len(todos) == 2
-    assert todos[0].due == datetime(
-        2016, 1, 2, 0, 0, tzinfo=tzoffset(None, -36000)
-    )
-    assert todos[1].due == datetime(
-        2016, 1, 2, 0, 0, tzinfo=tzoffset(None, 3600)
-    )
+    assert todos[0].due == datetime(2016, 1, 2, 0, 0, tzinfo=tzoffset(None, -36000))
+    assert todos[1].due == datetime(2016, 1, 2, 0, 0, tzinfo=tzoffset(None, 3600))
 
 
 def test_due_date(tmpdir, create, todos):
-    create('ar.ics', 'SUMMARY:blah.ar\n' 'DUE;VALUE=DATE:20170617\n')
+    create("ar.ics", "SUMMARY:blah.ar\nDUE;VALUE=DATE:20170617\n")
 
     todos = list(todos())
 
@@ -60,18 +55,17 @@ def test_due_date(tmpdir, create, todos):
 
 
 def test_change_paths(tmpdir, create):
-    old_todos = set('abcdefghijk')
+    old_todos = set("abcdefghijk")
     for x in old_todos:
-        create('{}.ics'.format(x), 'SUMMARY:{}\n'.format(x), x)
+        create("{}.ics".format(x), "SUMMARY:{}\n".format(x), x)
 
-    tmpdir.mkdir('3')
+    tmpdir.mkdir("3")
 
-    db = Database([tmpdir.join(x) for x in old_todos],
-                  tmpdir.join('cache.sqlite'))
+    db = Database([tmpdir.join(x) for x in old_todos], tmpdir.join("cache.sqlite"))
 
     assert {t.summary for t in db.todos()} == old_todos
 
-    db.paths = [str(tmpdir.join('3'))]
+    db.paths = [str(tmpdir.join("3"))]
     db.update_cache()
 
     assert len(list(db.lists())) == 1
@@ -79,53 +73,53 @@ def test_change_paths(tmpdir, create):
 
 
 def test_list_displayname(tmpdir):
-    tmpdir.join('default').mkdir()
-    with tmpdir.join('default').join('displayname').open('w') as f:
-        f.write('personal')
+    tmpdir.join("default").mkdir()
+    with tmpdir.join("default").join("displayname").open("w") as f:
+        f.write("personal")
 
-    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite3'))
+    db = Database([tmpdir.join("default")], tmpdir.join("cache.sqlite3"))
     list_ = next(db.lists())
 
-    assert list_.name == 'personal'
-    assert str(list_) == 'personal'
+    assert list_.name == "personal"
+    assert str(list_) == "personal"
 
 
 def test_list_colour(tmpdir):
-    tmpdir.join('default').mkdir()
-    with tmpdir.join('default').join('color').open('w') as f:
-        f.write('#8ab6d2')
+    tmpdir.join("default").mkdir()
+    with tmpdir.join("default").join("color").open("w") as f:
+        f.write("#8ab6d2")
 
-    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite3'))
+    db = Database([tmpdir.join("default")], tmpdir.join("cache.sqlite3"))
     list_ = next(db.lists())
 
-    assert list_.colour == '#8ab6d2'
+    assert list_.colour == "#8ab6d2"
 
 
 def test_list_colour_cache_invalidation(tmpdir, sleep):
-    tmpdir.join('default').mkdir()
-    with tmpdir.join('default').join('color').open('w') as f:
-        f.write('#8ab6d2')
+    tmpdir.join("default").mkdir()
+    with tmpdir.join("default").join("color").open("w") as f:
+        f.write("#8ab6d2")
 
-    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite3'))
+    db = Database([tmpdir.join("default")], tmpdir.join("cache.sqlite3"))
     list_ = next(db.lists())
 
-    assert list_.colour == '#8ab6d2'
+    assert list_.colour == "#8ab6d2"
 
     sleep()
 
-    with tmpdir.join('default').join('color').open('w') as f:
-        f.write('#f874fd')
+    with tmpdir.join("default").join("color").open("w") as f:
+        f.write("#f874fd")
 
-    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite3'))
+    db = Database([tmpdir.join("default")], tmpdir.join("cache.sqlite3"))
     list_ = next(db.lists())
 
-    assert list_.colour == '#f874fd'
+    assert list_.colour == "#f874fd"
 
 
 def test_list_no_colour(tmpdir):
-    tmpdir.join('default').mkdir()
+    tmpdir.join("default").mkdir()
 
-    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite3'))
+    db = Database([tmpdir.join("default")], tmpdir.join("cache.sqlite3"))
     list_ = next(db.lists())
 
     assert list_.colour is None
@@ -133,8 +127,8 @@ def test_list_no_colour(tmpdir):
 
 def test_database_priority_sorting(create, todos):
     for i in [1, 5, 9, 0]:
-        create('test{}.ics'.format(i), 'PRIORITY:{}\n'.format(i))
-    create('test_none.ics'.format(i), 'SUMMARY:No priority (eg: None)\n')
+        create("test{}.ics".format(i), "PRIORITY:{}\n".format(i))
+    create("test_none.ics", "SUMMARY:No priority (eg: None)\n")
 
     todos = list(todos())
 
@@ -149,33 +143,29 @@ def test_retain_unknown_fields(tmpdir, create, default_database):
     """
     Test that we retain unknown fields after a load/save cycle.
     """
-    create(
-        'test.ics', 'UID:AVERYUNIQUEID\n'
-        'SUMMARY:RAWR\n'
-        'X-RAWR-TYPE:Reptar\n'
-    )
+    create("test.ics", "UID:AVERYUNIQUEID\nSUMMARY:RAWR\nX-RAWR-TYPE:Reptar\n")
 
-    db = Database([tmpdir.join('default')], tmpdir.join('cache.sqlite'))
+    db = Database([tmpdir.join("default")], tmpdir.join("cache.sqlite"))
     todo = db.todo(1, read_only=False)
 
     todo.description = 'Rawr means "I love you" in dinosaur.'
     default_database.save(todo)
 
-    path = tmpdir.join('default').join('test.ics')
+    path = tmpdir.join("default").join("test.ics")
     with path.open() as f:
         vtodo = f.read()
     lines = vtodo.splitlines()
 
-    assert 'SUMMARY:RAWR' in lines
+    assert "SUMMARY:RAWR" in lines
     assert 'DESCRIPTION:Rawr means "I love you" in dinosaur.' in lines
-    assert 'X-RAWR-TYPE:Reptar' in lines
+    assert "X-RAWR-TYPE:Reptar" in lines
 
 
 def test_todo_setters(todo_factory):
     todo = todo_factory()
 
-    todo.description = 'A tea would be nice, thanks.'
-    assert todo.description == 'A tea would be nice, thanks.'
+    todo.description = "A tea would be nice, thanks."
+    assert todo.description == "A tea would be nice, thanks."
 
     todo.priority = 7
     assert todo.priority == 7
@@ -185,7 +175,7 @@ def test_todo_setters(todo_factory):
     assert todo.due == now
 
     todo.description = None
-    assert todo.description == ''
+    assert todo.description == ""
 
     todo.priority = None
     assert todo.priority == 0
@@ -197,7 +187,7 @@ def test_todo_setters(todo_factory):
     assert todo.due is None
 
 
-@freeze_time('2017-03-19-15')
+@freeze_time("2017-03-19-15")
 def test_is_completed():
     completed_at = datetime(2017, 3, 19, 14, tzinfo=pytz.UTC)
 
@@ -212,33 +202,21 @@ def test_is_completed():
     assert todo.is_completed is True
     assert todo.completed_at == datetime.now(pytz.UTC)
     assert todo.percent_complete == 100
-    assert todo.status == 'COMPLETED'
+    assert todo.status == "COMPLETED"
 
 
 @pytest.mark.parametrize(
-    'until',
-    [
-        '20990315T020000Z',  # TZ-aware UNTIL
-        '20990315T020000',  # TZ-naive UNTIL
-    ]
+    "until",
+    ["20990315T020000Z", "20990315T020000"],  # TZ-aware UNTIL  # TZ-naive UNTIL
 )
-@pytest.mark.parametrize(
-    'tz',
-    [
-        pytz.UTC,  # TZ-aware todos
-        None,  # TZ-naive todos
-    ]
-)
-@pytest.mark.parametrize('due', [
-    True,
-    False,
-])
+@pytest.mark.parametrize("tz", [pytz.UTC, None])  # TZ-aware todos  # TZ-naive todos
+@pytest.mark.parametrize("due", [True, False])
 def test_complete_recurring(default_database, due, todo_factory, tz, until):
     # We'll lose the milis when casting, so:
     now = datetime.now(tz).replace(microsecond=0)
 
-    if bool(tz) != bool(until.endswith('Z')):
-        pytest.skip('These combinations are invalid, as per the spec.')
+    if bool(tz) != bool(until.endswith("Z")):
+        pytest.skip("These combinations are invalid, as per the spec.")
 
     original_start = now
     if due:
@@ -246,7 +224,7 @@ def test_complete_recurring(default_database, due, todo_factory, tz, until):
     else:
         due = original_due = None
 
-    rrule = 'FREQ=DAILY;UNTIL={}'.format(until)
+    rrule = "FREQ=DAILY;UNTIL={}".format(until)
     todo = todo_factory(rrule=rrule, due=original_due, start=original_start)
 
     todo.complete()
@@ -273,13 +251,13 @@ def test_complete_recurring(default_database, due, todo_factory, tz, until):
 def test_save_recurring_related(default_database, todo_factory, todos):
     now = datetime.now(pytz.UTC)
     original_due = now + timedelta(hours=12)
-    rrule = 'FREQ=DAILY;UNTIL=20990315T020000Z'
+    rrule = "FREQ=DAILY;UNTIL=20990315T020000Z"
     todo = todo_factory(rrule=rrule, due=original_due)
     todo.complete()
 
     default_database.save(todo)
 
-    todos = todos(status='ANY')
+    todos = todos(status="ANY")
     todo = next(todos)
     assert todo.percent_complete == 100
     assert todo.is_completed is True
@@ -292,31 +270,31 @@ def test_save_recurring_related(default_database, todo_factory, todos):
 
 
 def test_todo_filename_absolute_path():
-    Todo(filename='test.ics')
+    Todo(filename="test.ics")
     with pytest.raises(ValueError):
-        Todo(filename='/test.ics')
+        Todo(filename="/test.ics")
 
 
 def test_list_equality(tmpdir):
-    list1 = List(path=str(tmpdir), name='test list')
-    list2 = List(path=str(tmpdir), name='test list')
-    list3 = List(path=str(tmpdir), name='yet another test list')
+    list1 = List(path=str(tmpdir), name="test list")
+    list2 = List(path=str(tmpdir), name="test list")
+    list3 = List(path=str(tmpdir), name="yet another test list")
 
     assert list1 == list2
     assert list1 != list3
-    assert list1 != 'test list'
+    assert list1 != "test list"
 
 
 def test_clone():
     now = datetime.now(tz=tzlocal())
 
     todo = Todo(new=True)
-    todo.summary = 'Organize a party'
-    todo.location = 'Home'
+    todo.summary = "Organize a party"
+    todo.location = "Home"
     todo.due = now
-    todo.uid = '123'
-    todo.id = '123'
-    todo.filename = '123.ics'
+    todo.uid = "123"
+    todo.id = "123"
+    todo.filename = "123.ics"
 
     clone = todo.clone()
 
@@ -330,25 +308,25 @@ def test_clone():
     assert clone.uid in clone.filename
 
 
-@freeze_time('2017, 3, 20')
+@freeze_time("2017, 3, 20")
 def test_todos_startable(tmpdir, runner, todo_factory, todos):
-    todo_factory(summary='started', start=datetime(2017, 3, 15))
-    todo_factory(summary='nostart')
-    todo_factory(summary='unstarted', start=datetime(2017, 3, 24))
+    todo_factory(summary="started", start=datetime(2017, 3, 15))
+    todo_factory(summary="nostart")
+    todo_factory(summary="unstarted", start=datetime(2017, 3, 24))
 
     todos = list(todos(startable=True))
 
     assert len(todos) == 2
     for todo in todos:
-        assert 'unstarted' not in todo.summary
+        assert "unstarted" not in todo.summary
 
 
 def test_filename_uid_colision(create, default_database, runner, todos):
-    create('ABC.ics', 'SUMMARY:My UID is not ABC\n' 'UID:NOTABC\n')
+    create("ABC.ics", "SUMMARY:My UID is not ABC\nUID:NOTABC\n")
     len(list(todos())) == 1
 
     todo = Todo(new=False)
-    todo.uid = 'ABC'
+    todo.uid = "ABC"
     todo.list = next(default_database.lists())
     default_database.save(todo)
 
@@ -356,17 +334,18 @@ def test_filename_uid_colision(create, default_database, runner, todos):
 
 
 def test_hide_cancelled(todos, todo_factory):
-    todo_factory(status='CANCELLED')
+    todo_factory(status="CANCELLED")
 
     assert len(list(todos())) == 0
-    assert len(list(todos(status='ANY'))) == 1
+    assert len(list(todos(status="ANY"))) == 1
 
 
 def test_illegal_start_suppression(create, default_database, todos):
     create(
-        'test.ics', 'SUMMARY:Start doing stuff\n'
-        'DUE;VALUE=DATE-TIME;TZID=CET:20170331T120000\n'
-        'DTSTART;VALUE=DATE-TIME;TZID=CET:20170331T140000\n'
+        "test.ics",
+        "SUMMARY:Start doing stuff\n"
+        "DUE;VALUE=DATE-TIME;TZID=CET:20170331T120000\n"
+        "DTSTART;VALUE=DATE-TIME;TZID=CET:20170331T140000\n",
     )
     todo = next(todos())
     assert todo.start is None
@@ -374,38 +353,37 @@ def test_illegal_start_suppression(create, default_database, todos):
 
 
 def test_default_status(create, todos):
-    create('test.ics', 'SUMMARY:Finish all these status tests\n')
+    create("test.ics", "SUMMARY:Finish all these status tests\n")
     todo = next(todos())
-    assert todo.status == 'NEEDS-ACTION'
+    assert todo.status == "NEEDS-ACTION"
 
 
 def test_nullify_field(default_database, todo_factory, todos):
     todo_factory(due=datetime.now())
 
-    todo = next(todos(status='ANY'))
+    todo = next(todos(status="ANY"))
     assert todo.due is not None
 
     todo.due = None
     default_database.save(todo)
 
-    todo = next(todos(status='ANY'))
+    todo = next(todos(status="ANY"))
     assert todo.due is None
 
 
 def test_duplicate_list(tmpdir):
-    tmpdir.join('personal1').mkdir()
-    with tmpdir.join('personal1').join('displayname').open('w') as f:
-        f.write('personal')
+    tmpdir.join("personal1").mkdir()
+    with tmpdir.join("personal1").join("displayname").open("w") as f:
+        f.write("personal")
 
-    tmpdir.join('personal2').mkdir()
-    with tmpdir.join('personal2').join('displayname').open('w') as f:
-        f.write('personal')
+    tmpdir.join("personal2").mkdir()
+    with tmpdir.join("personal2").join("displayname").open("w") as f:
+        f.write("personal")
 
     with pytest.raises(AlreadyExists):
         Database(
-            [tmpdir.join('personal1'),
-             tmpdir.join('personal2')],
-            tmpdir.join('cache.sqlite3'),
+            [tmpdir.join("personal1"), tmpdir.join("personal2")],
+            tmpdir.join("cache.sqlite3"),
         )
 
 
@@ -417,10 +395,10 @@ def test_unreadable_ics(todo_factory, todos, tmpdir):
     fail even if you run the tests as root (you shouldn't!!), but the same
     codepath is followed for readonly files, etc.
     """
-    tmpdir.join('default').join('fake.ics').mkdir()
+    tmpdir.join("default").join("fake.ics").mkdir()
     todo_factory()
 
-    with patch('logging.Logger.exception') as mocked_exception:
+    with patch("logging.Logger.exception") as mocked_exception:
         todos = list(todos())
 
     assert len(todos) == 1
