@@ -2,8 +2,12 @@ import logging
 import os
 import socket
 import sqlite3
-from datetime import date, datetime, timedelta
-from os.path import normpath, split
+from datetime import date
+from datetime import datetime
+from datetime import time
+from datetime import timedelta
+from os.path import normpath
+from os.path import split
 from uuid import uuid4
 
 import icalendar
@@ -23,9 +27,9 @@ LOCAL_TIMEZONE = tzlocal()
 
 
 class cached_property:  # noqa
-    '''A read-only @property that is only evaluated once. Only usable on class
+    """A read-only @property that is only evaluated once. Only usable on class
     instances' methods.
-    '''
+    """
 
     def __init__(self, fget, doc=None):
         self.__name__ = fget.__name__
@@ -66,7 +70,7 @@ class Todo:
         """
         self.list = list
         now = datetime.now(LOCAL_TIMEZONE)
-        self.uid = '{}@{}'.format(uuid4().hex, socket.gethostname())
+        self.uid = "{}@{}".format(uuid4().hex, socket.gethostname())
         self.list = list
 
         if new:
@@ -77,27 +81,25 @@ class Todo:
         # Default values for supported fields
         self.categories = []
         self.completed_at = None
-        self.description = ''
+        self.description = ""
         self.dtstamp = now
         self.due = None
         self.id = None
         self.last_modified = None
-        self.location = ''
+        self.location = ""
         self.percent_complete = 0
         self.priority = 0
-        self.rrule = ''
+        self.rrule = ""
         self.sequence = 0
         self.start = None
-        self.status = 'NEEDS-ACTION'
-        self.summary = ''
+        self.status = "NEEDS-ACTION"
+        self.summary = ""
 
         self.filename = filename or "{}.ics".format(self.uid)
         self.related = []
 
         if os.path.basename(self.filename) != self.filename:
-            raise ValueError(
-                'Must not be an absolute path: {}'.format(self.filename)
-            )
+            raise ValueError("Must not be an absolute path: {}".format(self.filename))
         self.mtime = mtime or datetime.now()
 
     def clone(self):
@@ -110,10 +112,12 @@ class Todo:
         todo = Todo(new=True, list=self.list)
 
         fields = (
-            Todo.STRING_FIELDS + Todo.INT_FIELDS + Todo.LIST_FIELDS +
-            Todo.DATETIME_FIELDS
+            Todo.STRING_FIELDS
+            + Todo.INT_FIELDS
+            + Todo.LIST_FIELDS
+            + Todo.DATETIME_FIELDS
         )
-        fields.remove('uid')
+        fields.remove("uid")
 
         for field in fields:
             setattr(todo, field, getattr(self, field))
@@ -121,35 +125,34 @@ class Todo:
         return todo
 
     STRING_FIELDS = [
-        'description',
-        'location',
-        'status',
-        'summary',
-        'uid',
-        'rrule',
+        "description",
+        "location",
+        "status",
+        "summary",
+        "uid",
+        "rrule",
     ]
     INT_FIELDS = [
-        'percent_complete',
-        'priority',
-        'sequence',
+        "percent_complete",
+        "priority",
+        "sequence",
     ]
     LIST_FIELDS = [
-        'categories',
+        "categories",
     ]
     DATETIME_FIELDS = [
-        'completed_at',
-        'created_at',
-        'dtstamp',
-        'start',
-        'due',
-        'last_modified',
+        "completed_at",
+        "created_at",
+        "dtstamp",
+        "start",
+        "due",
+        "last_modified",
     ]
     RRULE_FIELDS = [
-        'rrule',
+        "rrule",
     ]
     ALL_SUPPORTED_FIELDS = (
-        DATETIME_FIELDS + INT_FIELDS + LIST_FIELDS + RRULE_FIELDS +
-        STRING_FIELDS
+        DATETIME_FIELDS + INT_FIELDS + LIST_FIELDS + RRULE_FIELDS + STRING_FIELDS
     )
 
     VALID_STATUSES = (
@@ -167,44 +170,41 @@ class Todo:
 
         if name in Todo.RRULE_FIELDS:
             if value is None:
-                v = ''
+                v = ""
             else:
-                assert isinstance(value, str), (
-                       "Got {0} for {1} where str was expected"
-                       .format(type(value), name))
+                assert isinstance(
+                    value, str
+                ), "Got {0} for {1} where str was expected".format(type(value), name)
 
         if name in Todo.STRING_FIELDS:
             if value is None:
-                v = ''
+                v = ""
             else:
-                assert isinstance(value, str), (
-                       "Got {0} for {1} where str was expected"
-                       .format(type(value), name))
+                assert isinstance(
+                    value, str
+                ), "Got {0} for {1} where str was expected".format(type(value), name)
 
         if name in Todo.INT_FIELDS:
             if value is None:
                 v = 0
             else:
-                assert isinstance(value, int), (
-                       "Got {0} for {1} where int was expected"
-                       .format(type(value), name))
+                assert isinstance(
+                    value, int
+                ), "Got {0} for {1} where int was expected".format(type(value), name)
 
         if name in Todo.LIST_FIELDS:
             if value is None:
                 v = []
             else:
-                assert isinstance(value, list), (
-                       "Got {0} for {1} where list was expected"
-                       .format(type(value), name))
+                assert isinstance(
+                    value, list
+                ), "Got {0} for {1} where list was expected".format(type(value), name)
 
         return object.__setattr__(self, name, v)
 
     @property
     def is_completed(self):
-        return (
-            bool(self.completed_at)
-            or self.status in ('CANCELLED', 'COMPLETED')
-        )
+        return bool(self.completed_at) or self.status in ("CANCELLED", "COMPLETED")
 
     @property
     def is_recurring(self):
@@ -216,6 +216,9 @@ class Todo:
 
         recurrence = rrulestr(self.rrule, dtstart=dt)
 
+        if isinstance(dt, date) and not isinstance(dt, datetime):
+            dt = datetime.combine(dt, time.min)
+
         return recurrence.after(dt)
 
     def _create_next_instance(self):
@@ -246,44 +249,45 @@ class Todo:
 
         self.completed_at = datetime.now(tz=LOCAL_TIMEZONE)
         self.percent_complete = 100
-        self.status = 'COMPLETED'
+        self.status = "COMPLETED"
 
     @cached_property
     def path(self):
         return os.path.join(self.list.path, self.filename)
 
     def cancel(self):
-        self.status = 'CANCELLED'
+        self.status = "CANCELLED"
 
 
-class VtodoWritter:
+class VtodoWriter:
     """Writes a Todo as a VTODO file."""
+
     """Maps Todo field names to VTODO field names"""
     FIELD_MAP = {
-        'summary': 'summary',
-        'priority': 'priority',
-        'sequence': 'sequence',
-        'uid': 'uid',
-        'categories': 'categories',
-        'completed_at': 'completed',
-        'description': 'description',
-        'dtstamp': 'dtstamp',
-        'start': 'dtstart',
-        'due': 'due',
-        'location': 'location',
-        'percent_complete': 'percent-complete',
-        'priority': 'priority',
-        'status': 'status',
-        'created_at': 'created',
-        'last_modified': 'last-modified',
-        'rrule': 'rrule',
+        "summary": "summary",
+        "priority": "priority",
+        "sequence": "sequence",
+        "uid": "uid",
+        "categories": "categories",
+        "completed_at": "completed",
+        "description": "description",
+        "dtstamp": "dtstamp",
+        "start": "dtstart",
+        "due": "due",
+        "location": "location",
+        "percent_complete": "percent-complete",
+        "priority": "priority",
+        "status": "status",
+        "created_at": "created",
+        "last_modified": "last-modified",
+        "rrule": "rrule",
     }
 
     def __init__(self, todo):
         self.todo = todo
 
     def normalize_datetime(self, dt):
-        '''
+        """
         Eliminate several differences between dates, times and datetimes which
         are hindering comparison:
 
@@ -294,9 +298,9 @@ class VtodoWritter:
         Datetimes are cast to UTC because icalendar doesn't include the
         VTIMEZONE information upon serialization, and some clients have issues
         dealing with that.
-        '''
+        """
         if isinstance(dt, date) and not isinstance(dt, datetime):
-            dt = datetime(dt.year, dt.month, dt.day)
+            return dt
 
         if not dt.tzinfo:
             dt = dt.replace(tzinfo=LOCAL_TIMEZONE)
@@ -315,7 +319,7 @@ class VtodoWritter:
         if name in Todo.STRING_FIELDS:
             return value
 
-        raise Exception('Unknown field {} serialized.'.format(name))
+        raise Exception("Unknown field {} serialized.".format(name))
 
     def set_field(self, name, value):
         # If serialized value is None:
@@ -334,17 +338,16 @@ class VtodoWritter:
             self.vtodo.pop(target)
             if getattr(self.todo, source):
                 self.set_field(
-                    target,
-                    self.serialize_field(source, getattr(self.todo, source)),
+                    target, self.serialize_field(source, getattr(self.todo, source)),
                 )
 
         return self.vtodo
 
     def _read(self, path):
-        with open(path, 'rb') as f:
+        with open(path, "rb") as f:
             cal = f.read()
             cal = icalendar.Calendar.from_ical(cal)
-            for component in cal.walk('VTODO'):
+            for component in cal.walk("VTODO"):
                 return component
 
     def write(self):
@@ -359,10 +362,10 @@ class VtodoWritter:
         original = self._read(path)
         vtodo = self.serialize(original)
 
-        with open(path, 'rb') as f:
+        with open(path, "rb") as f:
             cal = icalendar.Calendar.from_ical(f.read())
             for index, component in enumerate(cal.subcomponents):
-                if component.get('uid', None) == self.todo.uid:
+                if component.get("uid", None) == self.todo.uid:
                     cal.subcomponents[index] = vtodo
 
         with AtomicWriter(path, overwrite=True).open() as f:
@@ -375,8 +378,8 @@ class VtodoWritter:
         c.add_component(vtodo)
 
         with AtomicWriter(path).open() as f:
-            c.add('prodid', 'io.barrera.todoman')
-            c.add('version', '2.0')
+            c.add("prodid", "io.barrera.todoman")
+            c.add("version", "2.0")
             f.write(c.to_ical().decode("UTF-8"))
 
         return vtodo
@@ -395,7 +398,7 @@ class Cache:
     may be used for filtering/sorting.
     """
 
-    SCHEMA_VERSION = 5
+    SCHEMA_VERSION = 7
 
     def __init__(self, path):
         self.cache_path = str(path)
@@ -414,8 +417,7 @@ class Cache:
         """Checks if the cache DB schema is the latest version."""
         try:
             return self._conn.execute(
-                'SELECT version FROM meta WHERE version = ?',
-                (Cache.SCHEMA_VERSION,),
+                "SELECT version FROM meta WHERE version = ?", (Cache.SCHEMA_VERSION,),
             ).fetchone()
         except sqlite3.OperationalError:
             return False
@@ -425,33 +427,34 @@ class Cache:
             return
 
         self._conn.executescript(
-            '''
+            """
             DROP TABLE IF EXISTS lists;
             DROP TABLE IF EXISTS files;
             DROP TABLE IF EXISTS todos;
-        '''
+        """
         )
 
         self._conn.execute('CREATE TABLE IF NOT EXISTS meta ("version" INT)')
 
         self._conn.execute(
-            'INSERT INTO meta (version) VALUES (?)',
-            (Cache.SCHEMA_VERSION,),
+            "INSERT INTO meta (version) VALUES (?)", (Cache.SCHEMA_VERSION,),
         )
 
         self._conn.execute(
-            '''
+            """
             CREATE TABLE IF NOT EXISTS lists (
                 "name" TEXT PRIMARY KEY,
                 "path" TEXT,
                 "colour" TEXT,
+                "mtime" INTEGER,
+
                 CONSTRAINT path_unique UNIQUE (path)
             );
-        '''
+        """
         )
 
         self._conn.execute(
-            '''
+            """
             CREATE TABLE IF NOT EXISTS files (
                 "path" TEXT PRIMARY KEY,
                 "list_name" TEXT,
@@ -460,11 +463,11 @@ class Cache:
                 CONSTRAINT path_unique UNIQUE (path),
                 FOREIGN KEY(list_name) REFERENCES lists(name) ON DELETE CASCADE
             );
-        '''
+        """
         )
 
         self._conn.execute(
-            '''
+            """
             CREATE TABLE IF NOT EXISTS todos (
                 "file_path" TEXT,
 
@@ -472,7 +475,9 @@ class Cache:
                 "uid" TEXT,
                 "summary" TEXT,
                 "due" INTEGER,
+                "due_dt" INTEGER,
                 "start" INTEGER,
+                "start_dt" INTEGER,
                 "priority" INTEGER,
                 "created_at" INTEGER,
                 "completed_at" INTEGER,
@@ -488,7 +493,7 @@ class Cache:
 
                 FOREIGN KEY(file_path) REFERENCES files(path) ON DELETE CASCADE
             );
-        '''
+        """
         )
 
     def clear(self):
@@ -496,7 +501,7 @@ class Cache:
         os.remove(self.cache_path)
         self._conn = None
 
-    def add_list(self, name, path, colour):
+    def add_list(self, name, path, colour, mtime):
         """
         Inserts a new list into the cache.
 
@@ -504,56 +509,64 @@ class Cache:
         """
 
         result = self._conn.execute(
-            'SELECT name FROM lists WHERE path = ?',
-            (path,),
+            "SELECT name FROM lists WHERE path = ?", (path,),
         ).fetchone()
 
         if result:
-            return result['name']
+            return result["name"]
 
         try:
             self._conn.execute(
-                "INSERT INTO lists (name, path, colour) VALUES (?, ?, ?)",
-                (
+                """
+                INSERT INTO lists (
                     name,
                     path,
                     colour,
-                ),
+                    mtime
+                ) VALUES (?, ?, ?, ?)
+                """,
+                (name, path, colour, mtime,),
             )
         except sqlite3.IntegrityError as e:
-            raise exceptions.AlreadyExists('list', name) from e
+            raise exceptions.AlreadyExists("list", name) from e
 
-        return self.add_list(name, path, colour)
+        return self.add_list(name, path, colour, mtime)
 
     def add_file(self, list_name, path, mtime):
         try:
             self._conn.execute(
-                '''
+                """
                 INSERT INTO files (
                     list_name,
                     path,
                     mtime
                 ) VALUES (?, ?, ?);
-                ''', (
-                    list_name,
-                    path,
-                    mtime,
-                )
+                """,
+                (list_name, path, mtime,),
             )
         except sqlite3.IntegrityError as e:
-            raise exceptions.AlreadyExists('file', list_name) from e
+            raise exceptions.AlreadyExists("file", list_name) from e
 
     def _serialize_datetime(self, todo, field):
+        """
+        Serialize a todo field in two value, the first one is the corresponding
+        timestamp, the second one is a boolean indicating if the serialized
+        value is a date or a datetime.
+
+        :param icalendar.Todo todo: An icalendar component object
+        :param str field: The name of the field to serialize
+        """
         dt = todo.decoded(field, None)
         if not dt:
-            return None
+            return None, None
 
-        if isinstance(dt, date) and not isinstance(dt, datetime):
+        is_date = isinstance(dt, date) and not isinstance(dt, datetime)
+        if is_date:
             dt = datetime(dt.year, dt.month, dt.day)
 
         if not dt.tzinfo:
             dt = dt.replace(tzinfo=LOCAL_TIMEZONE)
-        return dt.timestamp()
+        return dt.timestamp(), is_date
 
     def _serialize_rrule(self, todo, field):
         rrule = todo.get(field)
@@ -565,9 +578,9 @@ class Cache:
     def _serialize_categories(self, todo, field):
         categories = todo.get(field, [])
         if not categories:
-            return ''
+            return ""
 
-        return ','.join([str(category) for category in categories.cats])
+        return ",".join([str(category) for category in categories.cats])
 
     def add_vtodo(self, todo, file_path, id=None):
         """
@@ -576,14 +589,16 @@ class Cache:
         :param icalendar.Todo todo: The icalendar component object on which
         """
 
-        sql = '''
+        sql = """
             INSERT INTO todos (
                 {}
                 file_path,
                 uid,
                 summary,
                 due,
+                due_dt,
                 start,
+                start_dt,
                 priority,
                 created_at,
                 completed_at,
@@ -596,40 +611,43 @@ class Cache:
                 sequence,
                 last_modified,
                 rrule
-            ) VALUES ({}?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
-            '''
+            ) VALUES ({}?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?,
+                ?)
+            """
 
-        due = self._serialize_datetime(todo, 'due')
-        start = self._serialize_datetime(todo, 'dtstart')
+        due, due_dt = self._serialize_datetime(todo, "due")
+        start, start_dt = self._serialize_datetime(todo, "dtstart")
 
         if start and due:
             start = None if start >= due else start
 
         params = (
             file_path,
-            todo.get('uid'),
-            todo.get('summary'),
+            todo.get("uid"),
+            todo.get("summary"),
             due,
+            due_dt,
             start,
-            todo.get('priority', 0) or None,
-            self._serialize_datetime(todo, 'created'),
-            self._serialize_datetime(todo, 'completed'),
-            todo.get('percent-complete', None),
-            self._serialize_datetime(todo, 'dtstamp'),
-            todo.get('status', 'NEEDS-ACTION'),
-            todo.get('description', None),
-            todo.get('location', None),
-            self._serialize_categories(todo, 'categories'),
-            todo.get('sequence', 1),
-            self._serialize_datetime(todo, 'last-modified'),
-            self._serialize_rrule(todo, 'rrule'),
+            start_dt,
+            todo.get("priority", 0) or None,
+            self._serialize_datetime(todo, "created")[0],
+            self._serialize_datetime(todo, "completed")[0],
+            todo.get("percent-complete", None),
+            self._serialize_datetime(todo, "dtstamp")[0],
+            todo.get("status", "NEEDS-ACTION"),
+            todo.get("description", None),
+            todo.get("location", None),
+            self._serialize_categories(todo, "categories"),
+            todo.get("sequence", 1),
+            self._serialize_datetime(todo, "last-modified")[0],
+            self._serialize_rrule(todo, "rrule"),
         )
 
         if id:
             params = (id,) + params
-            sql = sql.format('id,\n', '?, ')
+            sql = sql.format("id,\n", "?, ")
         else:
-            sql = sql.format('', '')
+            sql = sql.format("", "")
 
         cursor = self._conn.cursor()
         try:
@@ -644,18 +662,15 @@ class Cache:
         self,
         lists=(),
         priority=None,
-        location='',
-        category='',
-        grep='',
+        location="",
+        category="",
+        grep="",
         sort=(),
         reverse=True,
         due=None,
         start=None,
         startable=False,
-        status=(
-            'NEEDS-ACTION',
-            'IN-PROCESS',
-        )
+        status=("NEEDS-ACTION", "IN-PROCESS",),
     ):
         """
         Returns filtered cached todos, in a specified order.
@@ -689,77 +704,78 @@ class Cache:
         extra_where = []
         params = []
 
-        if 'ANY' not in status:
+        if "ANY" not in status:
             extra_where.append(
-                'AND status IN ({})'.format(', '.join(['?'] * len(status)))
+                "AND status IN ({})".format(", ".join(["?"] * len(status)))
             )
             params.extend(s.upper() for s in status)
 
         if lists:
-            lists = [l.name if isinstance(l, List) else l for l in lists]
-            q = ', '.join(['?'] * len(lists))
-            extra_where.append('AND files.list_name IN ({})'.format(q))
+            lists = [
+                list_.name if isinstance(list_, List) else list_ for list_ in lists
+            ]
+            q = ", ".join(["?"] * len(lists))
+            extra_where.append("AND files.list_name IN ({})".format(q))
             params.extend(lists)
         if priority:
-            extra_where.append('AND PRIORITY > 0 AND PRIORITY <= ?')
-            params.append('{}'.format(priority))
+            extra_where.append("AND PRIORITY > 0 AND PRIORITY <= ?")
+            params.append("{}".format(priority))
         if location:
-            extra_where.append('AND location LIKE ?')
-            params.append('%{}%'.format(location))
+            extra_where.append("AND location LIKE ?")
+            params.append("%{}%".format(location))
         if category:
-            extra_where.append('AND categories LIKE ?')
-            params.append('%{}%'.format(category))
+            extra_where.append("AND categories LIKE ?")
+            params.append("%{}%".format(category))
         if grep:
             # # requires sqlite with pcre, which won't be available everywhere:
             # extra_where.append('AND summary REGEXP ?')
             # params.append(grep)
-            extra_where.append('AND summary LIKE ?')
-            params.append('%{}%'.format(grep))
+            extra_where.append("AND summary LIKE ?")
+            params.append("%{}%".format(grep))
         if due:
             max_due = (datetime.now() + timedelta(hours=due)).timestamp()
-            extra_where.append('AND due IS NOT NULL AND due < ?')
+            extra_where.append("AND due IS NOT NULL AND due < ?")
             params.append(max_due)
         if start:
             is_before, dt = start
             dt = dt.timestamp()
             if is_before:
-                extra_where.append('AND start <= ?')
+                extra_where.append("AND start <= ?")
                 params.append(dt)
             else:
-                extra_where.append('AND start >= ?')
+                extra_where.append("AND start >= ?")
                 params.append(dt)
         if startable:
-            extra_where.append('AND (start IS NULL OR start <= ?)')
+            extra_where.append("AND (start IS NULL OR start <= ?)")
             params.append(datetime.now().timestamp())
         if sort:
             order = []
             for s in sort:
-                if s.startswith('-'):
-                    order.append(' {} ASC'.format(s[1:]))
+                if s.startswith("-"):
+                    order.append(" {} ASC".format(s[1:]))
                 else:
-                    order.append(' {} DESC'.format(s))
-            order = ','.join(order)
+                    order.append(" {} DESC".format(s))
+            order = ",".join(order)
         else:
-            order = '''
+            order = """
                 completed_at DESC,
                 priority IS NOT NULL, priority DESC,
                 due IS NOT NULL, due DESC,
                 created_at ASC
-            '''
+            """
 
         if not reverse:
             # Note the change in case to avoid swapping all of them. sqlite
             # doesn't care about casing anyway.
-            order = order.replace(' DESC', ' asc').replace(' ASC', ' desc')
+            order = order.replace(" DESC", " asc").replace(" ASC", " desc")
 
-        query = '''
+        query = """
               SELECT todos.*, files.list_name, files.path
                 FROM todos, files
                WHERE todos.file_path = files.path {}
             ORDER BY {}
-        '''.format(
-            ' '.join(extra_where),
-            order,
+        """.format(
+            " ".join(extra_where), order,
         )
 
         logger.debug(query)
@@ -772,62 +788,67 @@ class Cache:
 
         for row in result:
             todo = self._todo_from_db(row)
-            path = row['path']
+            path = row["path"]
 
             if path in seen_paths and path not in warned_paths:
                 logger.warning(
-                    'Todo is in read-only mode because there are '
-                    'multiple todos in %s', path
+                    "Todo is in read-only mode because there are multiple todos in %s",
+                    path,
                 )
                 warned_paths.add(path)
             seen_paths.add(path)
             yield todo
 
-    def _dt_from_db(self, dt):
+    def _dt_from_db(self, dt, is_date=False):
         if dt:
-            return datetime.fromtimestamp(dt, LOCAL_TIMEZONE)
+            val = datetime.fromtimestamp(dt, LOCAL_TIMEZONE)
+            if is_date:
+                val = val.date()
+            return val
         return None
 
     def _todo_from_db(self, row):
         todo = Todo()
-        todo.id = row['id']
-        todo.uid = row['uid']
-        todo.summary = row['summary']
-        todo.due = self._dt_from_db(row['due'])
-        todo.start = self._dt_from_db(row['start'])
-        todo.priority = row['priority']
-        todo.created_at = self._dt_from_db(row['created_at'])
-        todo.completed_at = self._dt_from_db(row['completed_at'])
-        todo.dtstamp = self._dt_from_db(row['dtstamp'])
-        todo.percent_complete = row['percent_complete']
-        todo.status = row['status']
-        todo.description = row['description']
-        todo.location = row['location']
-        todo.sequence = row['sequence']
-        todo.last_modified = row['last_modified']
-        todo.list = self.lists_map[row['list_name']]
-        todo.filename = os.path.basename(row['path'])
-        todo.rrule = row['rrule']
+        todo.id = row["id"]
+        todo.uid = row["uid"]
+        todo.summary = row["summary"]
+        todo.due = self._dt_from_db(row["due"], row["due_dt"])
+        todo.start = self._dt_from_db(row["start"], row["start_dt"])
+        todo.priority = row["priority"]
+        todo.created_at = self._dt_from_db(row["created_at"])
+        todo.completed_at = self._dt_from_db(row["completed_at"])
+        todo.dtstamp = self._dt_from_db(row["dtstamp"])
+        todo.percent_complete = row["percent_complete"]
+        todo.status = row["status"]
+        todo.description = row["description"]
+        todo.location = row["location"]
+        todo.sequence = row["sequence"]
+        todo.last_modified = row["last_modified"]
+        todo.list = self.lists_map[row["list_name"]]
+        todo.filename = os.path.basename(row["path"])
+        todo.rrule = row["rrule"]
         return todo
 
     def lists(self):
         result = self._conn.execute("SELECT * FROM lists")
         for row in result:
             yield List(
-                name=row['name'],
-                path=row['path'],
-                colour=row['colour'],
+                name=row["name"], path=row["path"], colour=row["colour"],
             )
 
     @cached_property
     def lists_map(self):
-        return {l.name: l for l in self.lists()}
+        return {list_.name: list_ for list_ in self.lists()}
 
     def expire_lists(self, paths):
-        results = self._conn.execute("SELECT path, name from lists")
+        results = self._conn.execute("SELECT path, name, mtime from lists")
         for result in results:
-            if result['path'] not in paths:
-                self.delete_list(result['name'])
+            if result["path"] not in paths:
+                self.delete_list(result["name"])
+            else:
+                mtime = paths.get(result["path"])
+                if mtime and mtime > result["mtime"]:
+                    self.delete_list(result["name"])
 
     def delete_list(self, name):
         self._conn.execute("DELETE FROM lists WHERE lists.name = ?", (name,))
@@ -835,12 +856,13 @@ class Cache:
     def todo(self, id, read_only=False):
         # XXX: DON'T USE READ_ONLY
         result = self._conn.execute(
-            '''
+            """
             SELECT todos.*, files.list_name, files.path
               FROM todos, files
             WHERE files.path = todos.file_path
               AND todos.id = ?
-        ''', (id,)
+        """,
+            (id,),
         ).fetchone()
 
         if not result:
@@ -848,15 +870,16 @@ class Cache:
 
         if not read_only:
             count = self._conn.execute(
-                '''
+                """
                 SELECT count(id) AS c
                   FROM files, todos
                  WHERE todos.file_path = files.path
                    AND path=?
-            ''', (result['path'],)
+            """,
+                (result["path"],),
             ).fetchone()
-            if count['c'] > 1:
-                raise exceptions.ReadOnlyTodo(result['path'])
+            if count["c"] > 1:
+                raise exceptions.ReadOnlyTodo(result["path"])
 
         return self._todo_from_db(result)
 
@@ -864,7 +887,7 @@ class Cache:
         """Remove stale cache entries based on the given fresh data."""
         result = self._conn.execute("SELECT path, mtime FROM files")
         for row in result:
-            path, mtime = row['path'], row['mtime']
+            path, mtime = row["path"], row["mtime"]
             if paths_to_mtime.get(path, None) != mtime:
                 self.expire_file(path)
 
@@ -881,19 +904,35 @@ class List:
     @staticmethod
     def colour_for_path(path):
         try:
-            with open(os.path.join(path, 'color')) as f:
+            with open(os.path.join(path, "color")) as f:
                 return f.read().strip()
-        except (OSError, IOError):
-            logger.debug('No colour for list %s', path)
+        except OSError:
+            logger.debug("No colour for list %s", path)
 
     @staticmethod
     def name_for_path(path):
         try:
-            with open(os.path.join(path, 'displayname')) as f:
+            with open(os.path.join(path, "displayname")) as f:
                 return f.read().strip()
-        except (OSError, IOError):
+        except OSError:
             return split(normpath(path))[1]
 
+    @staticmethod
+    def mtime_for_path(path):
+        colour_file = os.path.join(path, "color")
+        display_file = os.path.join(path, "displayname")
+
+        mtimes = []
+        if os.path.exists(colour_file):
+            mtimes.append(_getmtime(colour_file))
+        if os.path.exists(display_file):
+            mtimes.append(_getmtime(display_file))
+
+        if mtimes:
+            return max(mtimes)
+        else:
+            return 0
+
     def __eq__(self, other):
         if isinstance(other, List):
             return self.name == other.name
@@ -918,19 +957,18 @@ class Database:
         self.update_cache()
 
     def update_cache(self):
-        self.cache.expire_lists(self.paths)
+        paths = {path: List.mtime_for_path(path) for path in self.paths}
+        self.cache.expire_lists(paths)
 
         paths_to_mtime = {}
         paths_to_list_name = {}
 
         for path in self.paths:
             list_name = self.cache.add_list(
-                List.name_for_path(path),
-                path,
-                List.colour_for_path(path),
+                List.name_for_path(path), path, List.colour_for_path(path), paths[path],
             )
             for entry in os.listdir(path):
-                if not entry.endswith('.ics'):
+                if not entry.endswith(".ics"):
                     continue
                 entry_path = os.path.join(path, entry)
                 mtime = _getmtime(entry_path)
@@ -945,14 +983,14 @@ class Database:
             try:
                 self.cache.add_file(list_name, entry_path, mtime)
             except exceptions.AlreadyExists:
-                logger.debug('File already in cache: %s', entry_path)
+                logger.debug("File already in cache: %s", entry_path)
                 continue
 
             try:
-                with open(entry_path, 'rb') as f:
+                with open(entry_path, "rb") as f:
                     cal = f.read()
                     cal = icalendar.Calendar.from_ical(cal)
-                    for component in cal.walk('VTODO'):
+                    for component in cal.walk("VTODO"):
                         self.cache.add_vtodo(component, entry_path)
             except Exception:
                 logger.exception("Failed to read entry %s.", entry_path)
@@ -980,7 +1018,7 @@ class Database:
         os.remove(path)
 
     def flush(self):
-        for todo in self.todos(status=['ANY']):
+        for todo in self.todos(status=["ANY"]):
             if todo.is_completed:
                 yield todo
                 self.delete(todo)
@@ -995,7 +1033,7 @@ class Database:
         todo.sequence += 1
         todo.last_modified = datetime.now(LOCAL_TIMEZONE)
 
-        vtodo = VtodoWritter(todo).write()
+        vtodo = VtodoWriter(todo).write()
 
         self.cache.expire_file(todo.path)
         mtime = _getmtime(todo.path)
@@ -1007,4 +1045,4 @@ class Database:
 
 def _getmtime(path):
     stat = os.stat(path)
-    return getattr(stat, 'st_mtime_ns', stat.st_mtime)
+    return getattr(stat, "st_mtime_ns", stat.st_mtime)
